.. uwhoisd documentation master file, created by
   sphinx-quickstart on Sun Sep  2 12:00:00 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to uwhoisd's documentation!
===================================

A 'Universal WHOIS' proxy server: you query it for information about a
particular domain, it works out the correct WHOIS server to query and gives
back the correct details.

It is only intended for use with domain names currently, but could be
generalised to work with other types of WHOIS server.

.. toctree::
   :maxdepth: 2

   changelog


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

